% The different dimensionless parameters are defined as
% lambda= viscosity ratio
% R= electrical conductivity ratio
% S= dielectric permittivity ratio
% Ca= Capillary number
% ReE= electrical Reynolds number
% M = Mason number
% k=the physicochemical parameter (Pe/Ca)
% beta=eleasticity parameter
% theta= polar angle in radians
% phi= azimuthal angle in radians
% Phi_t=tilt angle of the applied electric field

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Horizontal and vertical components of the applied  electric field
Ex=cos(theta_t);Ey=sin(theta_t);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Different harmonics in the main paper, denoted with a '^' above the notations, are represented with an extra 'c' at the end.
% For example $\hat{L}_{2,2}$ is denoted with 'Lc22' here.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% O(ReE) charge distribution
qs_ReE= -(1/2)*sin(theta)*(-45*cos(theta)^2*cos(phi)*R*S*Z31-45*cos(theta)^2*sin(phi)*R*S*Zc31+24*Z31*cos(phi)+24*Zc31*sin(phi)-90*cos(3*phi)*R*S*Z33-90*sin(3*phi)*R*S*Zc33-6*sin(phi)*R*S*Zc11+9*sin(phi)*R*S*Zc31-60*cos(theta)^2*cos(phi)*R*Z31-90*cos(theta)^2*cos(phi)*S*Z31-60*cos(theta)^2*sin(phi)*R*Zc31-90*cos(theta)^2*sin(phi)*S*Zc31-6*cos(phi)*R*S*Z11+9*cos(phi)*R*S*Z31-240*Z33*cos(3*phi)-240*Zc33*sin(3*phi)-16*Z11*cos(phi)-16*Zc11*sin(phi)-120*cos(theta)^2*cos(phi)*Z31-120*cos(theta)^2*sin(phi)*Zc31-12*cos(phi)*R*Z11+12*cos(phi)*R*Z31-8*cos(phi)*S*Z11+18*cos(phi)*S*Z31-12*sin(phi)*R*Zc11+12*sin(phi)*R*Zc31-8*sin(phi)*S*Zc11+18*sin(phi)*S*Zc31-120*cos(3*phi)*R*Z33-180*cos(3*phi)*S*Z33-120*sin(3*phi)*R*Zc33+90*cos(3*phi)*cos(theta)^2*R*S*Z33+90*sin(3*phi)*cos(theta)^2*R*S*Zc33+240*cos(3*phi)*cos(theta)^2*Z33+240*sin(3*phi)*cos(theta)^2*Zc33+120*cos(3*phi)*cos(theta)^2*R*Z33+180*cos(3*phi)*cos(theta)^2*S*Z33+120*sin(3*phi)*cos(theta)^2*R*Zc33+180*sin(3*phi)*cos(theta)^2*S*Zc33-180*sin(3*phi)*S*Zc33)/((3*R+4)*(R+2));

%%% where different 'Z' harmonincs are :

Z11 = -(54/5)*(R-S)*(M*Ex*(-1+beta1)*(R-S)*Ey^2-(5/36*((k-5*lambda-8)*beta1+5*lambda+8))*(R+2)^2*Ey+M*Ex^3*(-1+beta1)*(R-S))/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));
Z31 = (54/5)*(R-S)*(-1+beta1)*((5/27)*R^2*Ey+(M*Ex^3+M*Ex*Ey^2+(20/27)*Ey)*R-M*S*Ex^3-M*S*Ex*Ey^2+(20/27)*Ey)/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));
Z33 = -(9/5)*(R-S)*(-(5/9)*R^2*Ey+(M*Ex^3-3*M*Ex*Ey^2-(20/9)*Ey)*R-M*S*Ex^3+3*M*S*Ex*Ey^2-(20/9)*Ey)*(-1+beta1)/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));

Zc11= -(54/5)*(M*Ey*(-1+beta1)*(R-S)*Ex^2+(5/36*((k-5*lambda-2)*beta1+5*lambda+2))*(R+2)^2*Ex+M*Ey^3*(-1+beta1)*(R-S))*(R-S)/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));
Zc31= (54/5)*(R-S)*(-1+beta1)*((5/27)*R^2*Ex+(M*Ey*Ex^2+M*Ey^3+(20/27)*Ex)*R-M*S*Ex^2*Ey-M*S*Ey^3+(20/27)*Ex)/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));
Zc33 = -(27/5)*(R-S)*((5/27)*R^2*Ex+(M*Ey*Ex^2-(1/3)*M*Ey^3+(20/27)*Ex)*R-M*S*Ex^2*Ey+(1/3)*M*S*Ey^3+(20/27)*Ex)*(-1+beta1)/((R+2)^3*((k-5*lambda-5)*beta1+5*lambda+5));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Surfactant concentratrion harmonics of O(CaReE)

gRe20 = (621/35)*(-1+beta1)^2*M*((635/1242)*R^4*Ex*Ey+(M*Ex^4+2*M*Ex^2*Ey^2-(355/621)*Ey*(S-329/71)*Ex+M*Ey^4)*R^3+(-(41/23)*M*(-130/123+S)*Ex^4-(82/23)*Ey^2*M*(-130/123+S)*Ex^2-(640/207)*Ey*(S-89/64)*Ex-(41/23)*M*Ey^4*(-130/123+S))*R^2+((18/23)*M*(S^2-(35/9)*S+20/27)*Ex^4+(36/23)*Ey^2*M*(S^2-(35/9)*S+20/27)*Ex^2-(380/69*(S-55/171))*Ey*Ex+(18/23)*M*Ey^4*(S^2-(35/9)*S+20/27))*R+(80/69*(S-1/2))*M*S*Ex^4+(160/69*(S-1/2))*Ey^2*M*S*Ex^2-(2000/621*(S+1/5))*Ey*Ex+(80/69*(S-1/2))*M*Ey^4*S)*(R-S)*k/(((k-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^5*(R+4/3));
gRe22 = -(621/70)*(-(35/414*((k-5*lambda-5)*beta1+5*lambda+5))*Ex*Ey*R^4+(M*(-1+beta1)*Ex^4+(35/207*(S-5/3))*((k-5*lambda-5)*beta1+5*lambda+5)*Ey*Ex-M*Ey^4*(-1+beta1))*R^3+(-(41/23*(-1+beta1))*M*(-130/123+S)*Ex^4+(560/621*((k-5*lambda-5)*beta1+5*lambda+5))*(S+1/8)*Ey*Ex+(41/23*(-1+beta1))*M*Ey^4*(-130/123+S))*R^2+((18/23*(-1+beta1))*M*(S^2-(35/9)*S+20/27)*Ex^4+(980/621*((k-5*lambda-5)*beta1+5*lambda+5))*Ey*(S+5/7)*Ex-(18/23*(-1+beta1))*M*Ey^4*(S^2-(35/9)*S+20/27))*R+(80/69*(S-1/2))*(-1+beta1)*M*S*Ex^4+(560/621*((k-5*lambda-5)*beta1+5*lambda+5))*(S+1)*Ey*Ex-(80/69*(S-1/2))*(-1+beta1)*M*Ey^4*S)*(-1+beta1)*M*(R-S)*k/(((k-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^5*(R+4/3));
gRe40 = -(243/35)*(-4/3+R-2*S)*((10/27)*R^2*Ex*Ey+(M*Ex^4+2*M*Ex^2*Ey^2+M*Ey^4+(40/27)*Ex*Ey)*R-M*S*Ex^4-2*M*S*Ex^2*Ey^2-M*S*Ey^4+(40/27)*Ex*Ey)*(-1+beta1)^2*M*(R-S)*k/(((k-5*lambda-5)*beta1+5*lambda+5)*((k-9*lambda-9)*beta1+9*lambda+9)*(R+2)^4*(R+4/3));
gRe42 = (27/35)*(-4/3+R-2*S)*(Ex^2+Ey^2)*(-1+beta1)^2*(Ex-Ey)*M^2*(R-S)^2*k*(Ex+Ey)/(((k-5*lambda-5)*beta1+5*lambda+5)*((k-9*lambda-9)*beta1+9*lambda+9)*(R+2)^4*(R+4/3));
gRe44 = -(27/280)*(-4/3+R-2*S)*(-1+beta1)^2*M*(R-S)*(-(10/9)*R^2*Ex*Ey+(M*Ex^4-6*M*Ex^2*Ey^2+M*Ey^4-(40/9)*Ex*Ey)*R-M*S*Ex^4+6*M*S*Ex^2*Ey^2-M*S*Ey^4-(40/9)*Ex*Ey)*k/(((k-5*lambda-5)*beta1+5*lambda+5)*((k-9*lambda-9)*beta1+9*lambda+9)*(R+2)^4*(R+4/3));

gRec22 = (621/175)*M*(((((35/1656)*k-(175/1656)*lambda+965/7452)*beta1-965/7452+(175/1656)*lambda)*Ex^2-(35/1656*((k-5*lambda-1016/63)*beta1+5*lambda+1016/63))*Ey^2)*R^4+(M*Ey*(-1+beta1)*Ex^3+(((155/3726-(35/828)*k+(175/828)*lambda)*S+(175/2484)*k-(875/2484)*lambda+3955/3726)*beta1+(-(175/828)*lambda-155/3726)*S-3955/3726+(875/2484)*lambda)*Ex^2+M*Ey^3*(-1+beta1)*Ex+(35/828*(((k-5*lambda-568/63)*S-(5/3)*k+(25/3)*lambda+376/9)*beta1+(5*lambda+568/63)*S-(25/3)*lambda-376/9))*Ey^2)*R^3+(-(41/23*(-1+beta1))*M*Ey*(-130/123+S)*Ex^3+(((-(140/621)*k+(700/621)*lambda+40/207)*S+85/27-(35/1242)*k+(175/1242)*lambda)*beta1+(-40/207-(700/621)*lambda)*S-(175/1242)*lambda-85/27)*Ex^2-(41/23*(-1+beta1))*M*Ey^3*(-130/123+S)*Ex+(140/621)*Ey^2*(((k-5*lambda-64/7)*S+(1/8)*k-(5/8)*lambda+89/7)*beta1+(5*lambda+64/7)*S+(5/8)*lambda-89/7))*R^2+((18/23*(-1+beta1))*M*Ey*(S^2-(35/9)*S+20/27)*Ex^3+(((-(245/621)*k+(1225/621)*lambda+170/621)*S+7450/1863-(175/621)*k+(875/621)*lambda)*beta1+(-170/621-(1225/621)*lambda)*S-(875/621)*lambda-7450/1863)*Ex^2+(18/23*(-1+beta1))*M*Ey^3*(S^2-(35/9)*S+20/27)*Ex+(245/621*(((k-5*lambda-456/49)*S+(5/7)*k-(25/7)*lambda+440/147)*beta1+(5*lambda+456/49)*S+(25/7)*lambda-440/147))*Ey^2)*R+(80/69*(S-1/2))*(-1+beta1)*M*Ey*S*Ex^3+(((-(140/621)*k+(700/621)*lambda+200/1863)*S+3400/1863-(140/621)*k+(700/621)*lambda)*beta1+(-200/1863-(700/621)*lambda)*S-(700/621)*lambda-3400/1863)*Ex^2+(80/69*(S-1/2))*(-1+beta1)*M*Ey^3*S*Ex+(140/621*(((k-5*lambda-200/21)*S+k-5*lambda-40/21)*beta1+(5*lambda+200/21)*S+5*lambda+40/21))*Ey^2)*(R-S)*k/(((k-5*lambda-5)*beta1+5*lambda+5)*(R+2)^5*(lambda+1)*(R+4/3));
gRec42 = -(1/630)*M*(R-S)*(-1+beta1)*(Ex^2+Ey^2)*(-4+3*R-6*S)*(36*M*R*Ex*Ey-36*M*S*Ex*Ey+5*R^2+20*R+20)*k/(((k-5*lambda-5)*beta1+5*lambda+5)*(R+2)^4*(lambda+1)*(R+4/3));
gRec44 = (1/2520)*M*(R-S)*(-1+beta1)*(Ex-Ey)*(Ex+Ey)*(-4+3*R-6*S)*(36*M*R*Ex*Ey-36*M*S*Ex*Ey+5*R^2+20*R+20)*k/(((k-5*lambda-5)*beta1+5*lambda+5)*(R+2)^4*(lambda+1)*(R+4/3));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% O(Ca) deformation constants and surfactant distribution constants
L20 = -(3/8)*(K1*R^2*beta1*Ex^2+K1*R^2*beta1*Ey^2-5*R^2*beta1*lambda*Ex^2-5*R^2*beta1*lambda*Ey^2+2*K1*R*beta1*Ex^2+2*K1*R*beta1*Ey^2-4*K1*S*beta1*Ex^2-4*K1*S*beta1*Ey^2-5*R^2*beta1*Ex^2-5*R^2*beta1*Ey^2+5*R^2*lambda*Ex^2+5*R^2*lambda*Ey^2-9*R*beta1*lambda*Ex^2-9*R*beta1*lambda*Ey^2+19*S*beta1*lambda*Ex^2+19*S*beta1*lambda*Ey^2+K1*beta1*Ex^2+K1*beta1*Ey^2+5*R^2*Ex^2+5*R^2*Ey^2-6*R*beta1*Ex^2-6*R*beta1*Ey^2+9*R*lambda*Ex^2+9*R*lambda*Ey^2+16*S*beta1*Ex^2+16*S*beta1*Ey^2-19*S*lambda*Ex^2-19*S*lambda*Ey^2-5*beta1*lambda*Ex^2-5*beta1*lambda*Ey^2+6*R*Ex^2+6*R*Ey^2-16*S*Ex^2-16*S*Ey^2-5*beta1*Ex^2-5*beta1*Ey^2+5*lambda*Ex^2+5*lambda*Ey^2+5*Ex^2+5*Ey^2)*M/((R^2+4*R+4)*(K1*beta1-5*beta1*lambda-5*beta1+5*lambda+5));
L22 = (3/16)*(K1*R^2*beta1*Ex^2-K1*R^2*beta1*Ey^2-5*R^2*beta1*lambda*Ex^2+5*R^2*beta1*lambda*Ey^2+2*K1*R*beta1*Ex^2-2*K1*R*beta1*Ey^2-4*K1*S*beta1*Ex^2+4*K1*S*beta1*Ey^2-5*R^2*beta1*Ex^2+5*R^2*beta1*Ey^2+5*R^2*lambda*Ex^2-5*R^2*lambda*Ey^2-9*R*beta1*lambda*Ex^2+9*R*beta1*lambda*Ey^2+19*S*beta1*lambda*Ex^2-19*S*beta1*lambda*Ey^2+K1*beta1*Ex^2-K1*beta1*Ey^2+5*R^2*Ex^2-5*R^2*Ey^2-6*R*beta1*Ex^2+6*R*beta1*Ey^2+9*R*lambda*Ex^2-9*R*lambda*Ey^2+16*S*beta1*Ex^2-16*S*beta1*Ey^2-19*S*lambda*Ex^2+19*S*lambda*Ey^2-5*beta1*lambda*Ex^2+5*beta1*lambda*Ey^2+6*R*Ex^2-6*R*Ey^2-16*S*Ex^2+16*S*Ey^2-5*beta1*Ex^2+5*beta1*Ey^2+5*lambda*Ex^2-5*lambda*Ey^2+5*Ex^2-5*Ey^2)*M/((R^2+4*R+4)*(K1*beta1-5*beta1*lambda-5*beta1+5*lambda+5));
Lc22 = (1/48)*(((18*M*Ey*(K1-5*lambda-5)*Ex+20*K1-95*lambda-80)*R^2+((36*(K1-(9/2)*lambda-3))*M*Ey*Ex+80*K1-380*lambda-320)*R-72*M*Ey*((-(19/4)*S+5/4)*lambda+(S-1/4)*K1-4*S+5/4)*Ex+80*K1-380*lambda-320)*beta1+(90*M*Ey*(lambda+1)*Ex+95*lambda+80)*R^2+((162*(lambda+2/3))*M*Ey*Ex+380*lambda+320)*R-342*M*Ey*((S-5/19)*lambda+(16/19)*S-5/19)*Ex+380*lambda+320)/(((K1-5*lambda-5)*beta1+5*lambda+5)*(R+2)^2);

g120      = (3/2)*M*(Ex^2+Ey^2)*(R*beta1-S*beta1-R+S)*K1/((R^2+4*R+4)*(K1*beta1-5*beta1*lambda-5*beta1+5*lambda+5));
g122      = -(3/4)*M*(Ex^2-Ey^2)*(R*beta1-S*beta1-R+S)*K1/((R^2+4*R+4)*(K1*beta1-5*beta1*lambda-5*beta1+5*lambda+5));
g1c22    = -(1/12)*(-1+beta1)*(18*M*R*Ex*Ey-18*M*S*Ex*Ey+5*R^2+20*R+20)*K1/((R+2)^2*((K1-5*lambda-5)*beta1+5*lambda+5));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%Order (Ca) effective viscosity
ETA_CA= -(3/70)*((((6650*L22+625*L20)*lambda^2+((-2730*L22-350*g122-250*L20)*K1+(-600*g1c22+1025)*L20-600*Lc22*g120+12250*L22)*lambda+(280*L22+70*g122+25*L20)*K1^2+((120*g1c22-150)*L20+120*Lc22*g120-2520*L22-25*g120-350*g122)*K1+(-600*g1c22+100)*L20-600*Lc22*g120+5600*L22)*R^3+((39900*L22+3750*L20)*lambda^2+((-16380*L22-2100*g122-1500*L20)*K1+(-3240*Ex*Ey*L20+10800*Lc22*(Ex^2+Ey^2))*M+(-3600*g1c22+6150)*L20-3600*Lc22*g120+73500*L22)*lambda+(1680*L22+420*g122+150*L20)*K1^2+((846*Ex*Ey*L20+(-2358*Ex^2-2358*Ey^2)*Lc22-90*g120*Ex*Ey+90*g1c22*Ex^2+90*g1c22*Ey^2)*M+(720*g1c22-900)*L20+720*Lc22*g120-15120*L22-150*g120-2100*g122)*K1+(-4320*Ex*Ey*L20+11880*Lc22*(Ex^2+Ey^2))*M+(-3600*g1c22+600)*L20-3600*Lc22*g120+33600*L22)*R^2+((79800*L22+7500*L20)*lambda^2+((-32760*L22-4200*g122-3000*L20)*K1+((3240*(S+3/2))*Ex*Ey*L20-(10800*(Ex^2+Ey^2))*Lc22*(S+23/20))*M+(-7200*g1c22+12300)*L20-7200*Lc22*g120+147000*L22)*lambda+(3360*L22+840*g122+300*L20)*K1^2+((-846*Ex*(S+32/47)*Ey*L20+(2358*(S+116/131))*(Ex^2+Ey^2)*Lc22+(90*(S-2))*(-Ex^2*g1c22+Ex*Ey*g120-Ey^2*g1c22))*M+(1440*g1c22-1800)*L20+1440*Lc22*g120-30240*L22-300*g120-4200*g122)*K1+(4320*Ex*Ey*(S+5/8)*L20-(11880*(Ex^2+Ey^2))*(S+19/22)*Lc22)*M+(-7200*g1c22+1200)*L20-7200*Lc22*g120+67200*L22)*R+(53200*L22+5000*L20)*lambda^2+((-21840*L22-2800*g122-2000*L20)*K1+12420*S*(-(9/23)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+(-4800*g1c22+8200)*L20-4800*Lc22*g120+98000*L22)*lambda+(2240*L22+560*g122+200*L20)*K1^2+(180*S*((16/5)*Ex*Ey*L20+(-(58/5)*Ex^2-(58/5)*Ey^2)*Lc22+g120*Ex*Ey-g1c22*Ex^2-g1c22*Ey^2)*M+(960*g1c22-1200)*L20+960*Lc22*g120-20160*L22-200*g120-2800*g122)*K1+10260*S*(-(5/19)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+(-4800*g1c22+800)*L20-4800*Lc22*g120+44800*L22)*beta1^2+(((-13300*L22-1250*L20)*lambda^2+((2730*L22+350*g122+250*L20)*K1+(600*g1c22-2050)*L20+600*Lc22*g120-24500*L22)*lambda+(2520*L22+25*g120+350*g122+150*L20)*K1+(600*g1c22-200)*L20+600*Lc22*g120-11200*L22)*R^3+((-79800*L22-7500*L20)*lambda^2+((16380*L22+2100*g122+1500*L20)*K1+(6480*Ex*Ey*L20-21600*Lc22*(Ex^2+Ey^2))*M+(3600*g1c22-12300)*L20+3600*Lc22*g120-147000*L22)*lambda+((-846*Ex*Ey*L20+(2358*Ex^2+2358*Ey^2)*Lc22+90*g120*Ex*Ey-90*g1c22*Ex^2-90*g1c22*Ey^2)*M+15120*L22+150*g120+2100*g122+900*L20)*K1+(8640*Ex*Ey*L20-23760*Lc22*(Ex^2+Ey^2))*M+(3600*g1c22-1200)*L20+3600*Lc22*g120-67200*L22)*R^2+((-159600*L22-15000*L20)*lambda^2+((32760*L22+4200*g122+3000*L20)*K1+(-(6480*(S+3/2))*Ex*Ey*L20+(21600*(Ex^2+Ey^2))*Lc22*(S+23/20))*M+(7200*g1c22-24600)*L20+7200*Lc22*g120-294000*L22)*lambda+((846*Ex*(S+32/47)*Ey*L20-(2358*(S+116/131))*(Ex^2+Ey^2)*Lc22-(90*(S-2))*(-Ex^2*g1c22+Ex*Ey*g120-Ey^2*g1c22))*M+30240*L22+300*g120+4200*g122+1800*L20)*K1+(-8640*Ex*Ey*(S+5/8)*L20+(23760*(Ex^2+Ey^2))*(S+19/22)*Lc22)*M+(7200*g1c22-2400)*L20+7200*Lc22*g120-134400*L22)*R+(-106400*L22-10000*L20)*lambda^2+((21840*L22+2800*g122+2000*L20)*K1-24840*S*(-(9/23)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+(4800*g1c22-16400)*L20+4800*Lc22*g120-196000*L22)*lambda+(-180*S*((16/5)*Ex*Ey*L20+(-(58/5)*Ex^2-(58/5)*Ey^2)*Lc22+g120*Ex*Ey-g1c22*Ex^2-g1c22*Ey^2)*M+20160*L22+200*g120+2800*g122+1200*L20)*K1-20520*S*(-(5/19)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+(4800*g1c22-1600)*L20+4800*Lc22*g120-89600*L22)*beta1+((6650*L22+625*L20)*lambda^2+(12250*L22+1025*L20)*lambda+5600*L22+100*L20)*R^3+((39900*L22+3750*L20)*lambda^2+((-3240*Ex*Ey*L20+10800*Lc22*(Ex^2+Ey^2))*M+73500*L22+6150*L20)*lambda+(-4320*Ex*Ey*L20+11880*Lc22*(Ex^2+Ey^2))*M+33600*L22+600*L20)*R^2+((79800*L22+7500*L20)*lambda^2+(((3240*(S+3/2))*Ex*Ey*L20-(10800*(Ex^2+Ey^2))*Lc22*(S+23/20))*M+147000*L22+12300*L20)*lambda+(4320*Ex*Ey*(S+5/8)*L20-(11880*(Ex^2+Ey^2))*(S+19/22)*Lc22)*M+67200*L22+1200*L20)*R+(53200*L22+5000*L20)*lambda^2+(12420*S*(-(9/23)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+98000*L22+8200*L20)*lambda+10260*S*(-(5/19)*Ex*Ey*L20+Lc22*(Ex^2+Ey^2))*M+44800*L22+800*L20)/(((K1-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^3);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%Order (Ca) normal stress differences
N1_CA=  -(3/35)*nu*(((120*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5)*R^3+((((-2358*Ex^2-2358*Ey^2)*L22+(423*Ex^2-423*Ey^2)*L20+(-45*g120+90*g122)*Ex^2+45*Ey^2*(g120+2*g122))*K1+((10800*Ex^2+10800*Ey^2)*L22+(-1620*Ex^2+1620*Ey^2)*L20)*lambda+(11880*Ex^2+11880*Ey^2)*L22+(-2160*Ex^2+2160*Ey^2)*L20)*M+(720*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*R^2+((((2358*(Ex^2+Ey^2))*(S+116/131)*L22-(423*(S+32/47))*(Ex-Ey)*(Ex+Ey)*L20+(45*(S-2))*((g120-2*g122)*Ex^2-Ey^2*(g120+2*g122)))*K1+(-(10800*(S+23/20))*(Ex^2+Ey^2)*L22+(1620*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda-(11880*(S+19/22))*(Ex^2+Ey^2)*L22+(2160*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M+(1440*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*R-2088*S*(((Ex^2+Ey^2)*L22+(-(4/29)*Ex^2+(4/29)*Ey^2)*L20+(-(5/116)*g120+(5/58)*g122)*Ex^2+(5/116)*Ey^2*(g120+2*g122))*K1+((-(345/58)*Ex^2-(345/58)*Ey^2)*L22+(135/116)*L20*(Ex-Ey)*(Ex+Ey))*lambda+(-(285/58)*Ex^2-(285/58)*Ey^2)*L22+(75/116)*L20*(Ex-Ey)*(Ex+Ey))*M+(960*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*beta1^2+((((-2730*Lc22-350*g1c22)*lambda-2520*Lc22-350*g1c22)*K1+(600*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R^3+((((2358*Ex^2+2358*Ey^2)*L22+(-423*Ex^2+423*Ey^2)*L20+(45*g120-90*g122)*Ex^2-45*Ey^2*(g120+2*g122))*K1+((-21600*Ex^2-21600*Ey^2)*L22+(3240*Ex^2-3240*Ey^2)*L20)*lambda+(-23760*Ex^2-23760*Ey^2)*L22+(4320*Ex^2-4320*Ey^2)*L20)*M+((-16380*Lc22-2100*g1c22)*lambda-15120*Lc22-2100*g1c22)*K1+(3600*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R^2+(((-(2358*(Ex^2+Ey^2))*(S+116/131)*L22+(423*(S+32/47))*(Ex-Ey)*(Ex+Ey)*L20-(45*(S-2))*((g120-2*g122)*Ex^2-Ey^2*(g120+2*g122)))*K1+((21600*(S+23/20))*(Ex^2+Ey^2)*L22-(3240*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda+(23760*(S+19/22))*(Ex^2+Ey^2)*L22-(4320*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M+((-32760*Lc22-4200*g1c22)*lambda-30240*Lc22-4200*g1c22)*K1+(7200*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R+2088*S*(((Ex^2+Ey^2)*L22+(-(4/29)*Ex^2+(4/29)*Ey^2)*L20+(-(5/116)*g120+(5/58)*g122)*Ex^2+(5/116)*Ey^2*(g120+2*g122))*K1+((-(345/29)*Ex^2-(345/29)*Ey^2)*L22+(135/58)*L20*(Ex-Ey)*(Ex+Ey))*lambda+(-(285/29)*Ex^2-(285/29)*Ey^2)*L22+(75/58)*L20*(Ex-Ey)*(Ex+Ey))*M+((-21840*Lc22-2800*g1c22)*lambda-20160*Lc22-2800*g1c22)*K1+(4800*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*beta1-(6650*(lambda+1))*Lc22*(lambda+16/19)*R^3+((((10800*Ex^2+10800*Ey^2)*L22+(-1620*Ex^2+1620*Ey^2)*L20)*lambda+(11880*Ex^2+11880*Ey^2)*L22+(-2160*Ex^2+2160*Ey^2)*L20)*M-(39900*(lambda+1))*Lc22*(lambda+16/19))*R^2+(((-(10800*(S+23/20))*(Ex^2+Ey^2)*L22+(1620*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda-(11880*(S+19/22))*(Ex^2+Ey^2)*L22+(2160*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M-(79800*(lambda+1))*Lc22*(lambda+16/19))*R+12420*S*(((Ex^2+Ey^2)*L22+L20*(-(9/46)*Ex^2+(9/46)*Ey^2))*lambda+((19/23)*Ex^2+(19/23)*Ey^2)*L22+L20*(-(5/46)*Ex^2+(5/46)*Ey^2))*M-(53200*(lambda+1))*Lc22*(lambda+16/19))/(((K1-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^3) ;
N2_CA=  (3/2)*nu*((1/35)*(((120*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5)*R^3+((((-2358*Ex^2-2358*Ey^2)*L22+(423*Ex^2-423*Ey^2)*L20+(-45*g120+90*g122)*Ex^2+45*Ey^2*(g120+2*g122))*K1+((10800*Ex^2+10800*Ey^2)*L22+(-1620*Ex^2+1620*Ey^2)*L20)*lambda+(11880*Ex^2+11880*Ey^2)*L22+(-2160*Ex^2+2160*Ey^2)*L20)*M+(720*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*R^2+((((2358*(Ex^2+Ey^2))*(S+116/131)*L22-(423*(S+32/47))*(Ex-Ey)*(Ex+Ey)*L20+(45*(S-2))*((g120-2*g122)*Ex^2-Ey^2*(g120+2*g122)))*K1+(-(10800*(S+23/20))*(Ex^2+Ey^2)*L22+(1620*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda-(11880*(S+19/22))*(Ex^2+Ey^2)*L22+(2160*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M+(1440*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*R-2088*S*(((Ex^2+Ey^2)*L22+(-(4/29)*Ex^2+(4/29)*Ey^2)*L20+(-(5/116)*g120+(5/58)*g122)*Ex^2+(5/116)*Ey^2*(g120+2*g122))*K1+((-(345/58)*Ex^2-(345/58)*Ey^2)*L22+(135/116)*L20*(Ex-Ey)*(Ex+Ey))*lambda+(-(285/58)*Ex^2-(285/58)*Ey^2)*L22+(75/116)*L20*(Ex-Ey)*(Ex+Ey))*M+(960*((-(7/3)*Lc22-(7/12)*g1c22)*K1+L22*g120+(133/12)*Lc22*lambda+L20*g122+(28/3)*Lc22))*(K1-5*lambda-5))*beta1^2+((((-2730*Lc22-350*g1c22)*lambda-2520*Lc22-350*g1c22)*K1+(600*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R^3+((((2358*Ex^2+2358*Ey^2)*L22+(-423*Ex^2+423*Ey^2)*L20+(45*g120-90*g122)*Ex^2-45*Ey^2*(g120+2*g122))*K1+((-21600*Ex^2-21600*Ey^2)*L22+(3240*Ex^2-3240*Ey^2)*L20)*lambda+(-23760*Ex^2-23760*Ey^2)*L22+(4320*Ex^2-4320*Ey^2)*L20)*M+((-16380*Lc22-2100*g1c22)*lambda-15120*Lc22-2100*g1c22)*K1+(3600*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R^2+(((-(2358*(Ex^2+Ey^2))*(S+116/131)*L22+(423*(S+32/47))*(Ex-Ey)*(Ex+Ey)*L20-(45*(S-2))*((g120-2*g122)*Ex^2-Ey^2*(g120+2*g122)))*K1+((21600*(S+23/20))*(Ex^2+Ey^2)*L22-(3240*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda+(23760*(S+19/22))*(Ex^2+Ey^2)*L22-(4320*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M+((-32760*Lc22-4200*g1c22)*lambda-30240*Lc22-4200*g1c22)*K1+(7200*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*R+2088*S*(((Ex^2+Ey^2)*L22+(-(4/29)*Ex^2+(4/29)*Ey^2)*L20+(-(5/116)*g120+(5/58)*g122)*Ex^2+(5/116)*Ey^2*(g120+2*g122))*K1+((-(345/29)*Ex^2-(345/29)*Ey^2)*L22+(135/58)*L20*(Ex-Ey)*(Ex+Ey))*lambda+(-(285/29)*Ex^2-(285/29)*Ey^2)*L22+(75/58)*L20*(Ex-Ey)*(Ex+Ey))*M+((-21840*Lc22-2800*g1c22)*lambda-20160*Lc22-2800*g1c22)*K1+(4800*(L22*g120+(133/6)*Lc22*lambda+L20*g122+(56/3)*Lc22))*(lambda+1))*beta1-(6650*(lambda+1))*Lc22*(lambda+16/19)*R^3+((((10800*Ex^2+10800*Ey^2)*L22+(-1620*Ex^2+1620*Ey^2)*L20)*lambda+(11880*Ex^2+11880*Ey^2)*L22+(-2160*Ex^2+2160*Ey^2)*L20)*M-(39900*(lambda+1))*Lc22*(lambda+16/19))*R^2+(((-(10800*(S+23/20))*(Ex^2+Ey^2)*L22+(1620*(Ex-Ey))*(S+3/2)*(Ex+Ey)*L20)*lambda-(11880*(S+19/22))*(Ex^2+Ey^2)*L22+(2160*(Ex-Ey))*(Ex+Ey)*(S+5/8)*L20)*M-(79800*(lambda+1))*Lc22*(lambda+16/19))*R+12420*S*(((Ex^2+Ey^2)*L22+L20*(-(9/46)*Ex^2+(9/46)*Ey^2))*lambda+((19/23)*Ex^2+(19/23)*Ey^2)*L22+L20*(-(5/46)*Ex^2+(5/46)*Ey^2))*M-(53200*(lambda+1))*Lc22*(lambda+16/19))/(((K1-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^3)+(1/35)*(((150*K1^2*Lc22+(-1500*Lc22*lambda+(720*g1c22-900)*Lc22+720*L22*g122-60*L20*g120-150*g1c22)*K1+3750*Lc22*lambda^2+((-3600*g1c22+6150)*Lc22-3600*L22*g122+300*L20*g120)*lambda+(-3600*g1c22+600)*Lc22-3600*L22*g122+300*L20*g120)*R^3+((((2538*L22-45*g120-270*g122-333*L20)*Ex^2+(5076*(-(5/47)*g1c22+Lc22))*Ey*Ex-(2538*(L22+(5/282)*g120-(5/47)*g122+(37/282)*L20))*Ey^2)*K1+((-9720*L22+2160*L20)*lambda-12960*L22+1620*L20)*Ex^2-(19440*(lambda+4/3))*Lc22*Ey*Ex+(9720*((L22+(2/9)*L20)*lambda+(4/3)*L22+(1/6)*L20))*Ey^2)*M+900*K1^2*Lc22+(-9000*Lc22*lambda+(4320*g1c22-5400)*Lc22+4320*L22*g122-360*L20*g120-900*g1c22)*K1+22500*Lc22*lambda^2+((-21600*g1c22+36900)*Lc22-21600*L22*g122+1800*L20*g120)*lambda+(-21600*g1c22+3600)*Lc22-21600*L22*g122+1800*L20*g120)*R^2+(((((-2538*L22+45*g120+270*g122+333*L20)*S-1728*L22-90*g120-540*g122+468*L20)*Ex^2-(5076*((S+32/47)*Lc22-(5/47)*g1c22*(S-2)))*Ey*Ex+2538*Ey^2*((L22+(5/282)*g120-(5/47)*g122+(37/282)*L20)*S+(32/47)*L22+(10/47)*g122-(5/141)*g120+(26/141)*L20))*K1+(((9720*L22-2160*L20)*S+14580*L22-1350*L20)*lambda+(12960*L22-1620*L20)*S+8100*L22-2430*L20)*Ex^2+(19440*((S+3/2)*lambda+(4/3)*S+5/6))*Lc22*Ey*Ex-(9720*(((L22+(2/9)*L20)*S+(3/2)*L22+(5/36)*L20)*lambda+((4/3)*L22+(1/6)*L20)*S+(5/6)*L22+(1/4)*L20))*Ey^2)*M+1800*K1^2*Lc22+(-18000*Lc22*lambda+(8640*g1c22-10800)*Lc22+8640*L22*g122-720*L20*g120-1800*g1c22)*K1+45000*Lc22*lambda^2+((-43200*g1c22+73800)*Lc22-43200*L22*g122+3600*L20*g120)*lambda+(-43200*g1c22+7200)*Lc22-43200*L22*g122+3600*L20*g120)*R+1728*S*(((L22+(5/96)*g120+(5/16)*g122-(13/48)*L20)*Ex^2+(2*(Lc22+(5/16)*g1c22))*Ey*Ex-Ey^2*(L22-(5/96)*g120+(5/16)*g122+(13/48)*L20))*K1+((-(135/16)*L22+(25/32)*L20)*lambda-(75/16)*L22+(45/32)*L20)*Ex^2-(135/8)*Lc22*Ey*(lambda+5/9)*Ex+(135/16*((L22+(5/54)*L20)*lambda+(5/9)*L22+(1/6)*L20))*Ey^2)*M+1200*K1^2*Lc22+(-12000*Lc22*lambda+(5760*g1c22-7200)*Lc22+5760*L22*g122-480*L20*g120-1200*g1c22)*K1+30000*Lc22*lambda^2+((-28800*g1c22+49200)*Lc22-28800*L22*g122+2400*L20*g120)*lambda+(-28800*g1c22+4800)*Lc22-28800*L22*g122+2400*L20*g120)*beta1^2+(((1500*lambda*Lc22+900*Lc22+150*g1c22)*K1-7500*Lc22*lambda^2+((3600*g1c22-12300)*Lc22+3600*L22*g122-300*L20*g120)*lambda+(3600*g1c22-1200)*Lc22+3600*L22*g122-300*L20*g120)*R^3+((((-2538*L22+45*g120+270*g122+333*L20)*Ex^2-(5076*(-(5/47)*g1c22+Lc22))*Ey*Ex+(2538*(L22+(5/282)*g120-(5/47)*g122+(37/282)*L20))*Ey^2)*K1+((19440*L22-4320*L20)*lambda+25920*L22-3240*L20)*Ex^2+(38880*(lambda+4/3))*Lc22*Ey*Ex-(19440*((L22+(2/9)*L20)*lambda+(4/3)*L22+(1/6)*L20))*Ey^2)*M+(9000*lambda*Lc22+5400*Lc22+900*g1c22)*K1-45000*Lc22*lambda^2+((21600*g1c22-73800)*Lc22+21600*L22*g122-1800*L20*g120)*lambda+(21600*g1c22-7200)*Lc22+21600*L22*g122-1800*L20*g120)*R^2+(((((2538*L22-45*g120-270*g122-333*L20)*S+1728*L22+90*g120+540*g122-468*L20)*Ex^2+(5076*((S+32/47)*Lc22-(5/47)*g1c22*(S-2)))*Ey*Ex-2538*Ey^2*((L22+(5/282)*g120-(5/47)*g122+(37/282)*L20)*S+(32/47)*L22+(10/47)*g122-(5/141)*g120+(26/141)*L20))*K1+(((-19440*L22+4320*L20)*S-29160*L22+2700*L20)*lambda+(-25920*L22+3240*L20)*S-16200*L22+4860*L20)*Ex^2-(38880*((S+3/2)*lambda+(4/3)*S+5/6))*Lc22*Ey*Ex+(19440*(((L22+(2/9)*L20)*S+(3/2)*L22+(5/36)*L20)*lambda+((4/3)*L22+(1/6)*L20)*S+(5/6)*L22+(1/4)*L20))*Ey^2)*M+(18000*lambda*Lc22+10800*Lc22+1800*g1c22)*K1-90000*Lc22*lambda^2+((43200*g1c22-147600)*Lc22+43200*L22*g122-3600*L20*g120)*lambda+(43200*g1c22-14400)*Lc22+43200*L22*g122-3600*L20*g120)*R-1728*S*(((L22+(5/96)*g120+(5/16)*g122-(13/48)*L20)*Ex^2+(2*(Lc22+(5/16)*g1c22))*Ey*Ex-Ey^2*(L22-(5/96)*g120+(5/16)*g122+(13/48)*L20))*K1+((-(135/8)*L22+(25/16)*L20)*lambda-(75/8)*L22+(45/16)*L20)*Ex^2-(135/4)*Lc22*Ey*(lambda+5/9)*Ex+(135/8*((L22+(5/54)*L20)*lambda+(5/9)*L22+(1/6)*L20))*Ey^2)*M+(12000*lambda*Lc22+7200*Lc22+1200*g1c22)*K1-60000*Lc22*lambda^2+((28800*g1c22-98400)*Lc22+28800*L22*g122-2400*L20*g120)*lambda+(28800*g1c22-9600)*Lc22+28800*L22*g122-2400*L20*g120)*beta1+3750*Lc22*(lambda^2+(41/25)*lambda+4/25)*R^3+((((-9720*L22+2160*L20)*lambda-12960*L22+1620*L20)*Ex^2-(19440*(lambda+4/3))*Lc22*Ey*Ex+(9720*((L22+(2/9)*L20)*lambda+(4/3)*L22+(1/6)*L20))*Ey^2)*M+22500*Lc22*(lambda^2+(41/25)*lambda+4/25))*R^2+(((((9720*L22-2160*L20)*S+14580*L22-1350*L20)*lambda+(12960*L22-1620*L20)*S+8100*L22-2430*L20)*Ex^2+(19440*((S+3/2)*lambda+(4/3)*S+5/6))*Lc22*Ey*Ex-(9720*(((L22+(2/9)*L20)*S+(3/2)*L22+(5/36)*L20)*lambda+((4/3)*L22+(1/6)*L20)*S+(5/6)*L22+(1/4)*L20))*Ey^2)*M+45000*Lc22*(lambda^2+(41/25)*lambda+4/25))*R-14580*S*(((L22-(5/54)*L20)*lambda+(5/9)*L22-(1/6)*L20)*Ex^2+2*Lc22*Ey*(lambda+5/9)*Ex-((L22+(5/54)*L20)*lambda+(5/9)*L22+(1/6)*L20)*Ey^2)*M+30000*Lc22*(lambda^2+(41/25)*lambda+4/25))/(((K1-5*lambda-5)*beta1+5*lambda+5)^2*(R+2)^3)) ;
